@@ -1,3 +1,17 @@
+/*
+ * blogger.c
+ *
+ * Copyright 2000 Werner Fink, 2000 SuSE GmbH Nuernberg, Germany.
+ *
+ * This source is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ */
+
+#ifndef  _GNU_SOURCE
+# define _GNU_SOURCE
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
